@@ -59,6 +59,12 @@
 #' @references A. Kowarik, M. Templ (2016) Imputation with
 #' R package VIM.  *Journal of
 #' Statistical Software*, 74(7), 1-16.
+#' 
+#' M. Templ (2023) *Visualization and Imputation of Missing Values*. 
+#' Springer Publishing.
+#' Series in Computational Statistics. Cham. Switzerland. 463 pages. 
+#' DOI: 10.1007/978-3-031-30073-8
+#' 
 #' @keywords manip
 #' @family imputation methods
 #' @examples
@@ -590,26 +596,30 @@ irmi <- function(x, eps = 5, maxit = 100, mixed = NULL, mixed.constant = NULL,
 
 ### utility functions
 anyNA <- function(X) any(is.na(X))
+
 Unit <- function(A) UseMethod("Unit")
+
 #' @export
 #' @method Unit list
 Unit.list <- function(A) {
   # Units a list of vectors into one vector
   a <- vector()
-  for (i in 1:length(A)) {
+  for (i in seq_along(A)) {
     a <- c(a, A[[i]])
   }
   levels(as.factor(a))
 }
+
 Inter <- function(A) UseMethod("Inter")
+
 #' @export
 #' @method Inter list
 Inter.list <- function(A) {
   # common entries from a list of vectors
   a <- Unit(A)
   TF <- rep(TRUE, length(a))
-  for (i in 1:length(a)) {
-    for (j in 1:length(A)) {
+  for (i in seq_along(a)) {
+    for (j in seq_along(A)) {
       TF[i] <- TF[i] && a[i] %in% A[[j]]
     }
   }
